==> fess-fess_tags_fess-6.0.0-r1348.tar.gz: fess-fess_tags_fess-6.0.0-r1348/fess-6.0.0/src/main/java/jp/sf/fess/ds/impl/AbstractDataStoreImpl.java <==
/*
 * Copyright 2009-2012 the Fess Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package jp.sf.fess.ds.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import jp.sf.fess.Constants;
import jp.sf.fess.FessSystemException;
import jp.sf.fess.db.exentity.DataCrawlingConfig;
import jp.sf.fess.ds.DataStore;
import jp.sf.fess.ds.IndexUpdateCallback;

import org.seasar.framework.util.OgnlUtil;
import org.seasar.framework.util.StringUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public abstract class AbstractDataStoreImpl implements DataStore {

    private static final Logger logger = LoggerFactory
            .getLogger(AbstractDataStoreImpl.class);

    public String mimeType = "application/datastore";

    protected boolean alive = true;

    protected Map<String, String> parseParameter(final String value) {
        final Map<String, String> paramMap = new HashMap<String, String>();
        if (value != null) {
            final String[] lines = value.split("[\r\n]");
            for (final String line : lines) {
                if (StringUtil.isNotBlank(line)) {
                    final int pos = line.indexOf('=');
                    if (pos == 0) {
                        throw new FessSystemException(
                                "Invalid parameter. The key is null.");
                    } else if (pos > 0) {
                        if (pos < line.length()) {
                            paramMap.put(line.substring(0, pos).trim(),
                                    line.substring(pos + 1));
                        } else {
                            paramMap.put(line.substring(0, pos).trim(),
                                    Constants.EMPTY_STRING);
                        }
                    } else {
                        paramMap.put(line.trim(), Constants.EMPTY_STRING);
                    }
                }
            }
        }
        return paramMap;
    }

    protected Map<String, String> parseScript(final String value) {
        final Map<String, String> scriptMap = new HashMap<String, String>();
        if (value != null) {
            final String[] lines = value.split("[\r\n]");
            for (final String line : lines) {
                if (StringUtil.isNotBlank(line)) {
                    final int pos = line.indexOf('=');
                    if (pos == 0) {
                        throw new FessSystemException(
                                "Invalid parameter. The key is null.");
                    } else if (pos > 0) {
                        if (pos < line.length()) {
                            scriptMap.put(line.substring(0, pos).trim(), line
                                    .substring(pos + 1).trim());
                        } else {
                            scriptMap.put(line.substring(0, pos).trim(),
                                    Constants.EMPTY_STRING);
                        }
                    } else {
                        scriptMap.put(line.trim(), Constants.EMPTY_STRING);
                    }
                }
            }
        }
        return scriptMap;
    }

    @Override
    public void stop() {
        alive = false;
    }

    @Override
    public void store(final DataCrawlingConfig config,
            final IndexUpdateCallback callback,
            final Map<String, String> initParamMap) {
        Map<String, String> paramMap = parseParameter(config
                .getHandlerParameter());
        final Map<String, String> scriptMap = parseScript(config
                .getHandlerScript());

        initParamMap.putAll(paramMap);
        paramMap = initParamMap;

        // default values
        final Map<String, Object> defaultDataMap = new HashMap<String, Object>();
        // segment
        defaultDataMap.put("segment", initParamMap.get("sessionId"));
        // tstamp
        defaultDataMap.put("tstamp", Long.toString(new Date().getTime()));
        // boost
        defaultDataMap.put("boost", config.getBoost().toString());
        // type: browserType
        final List<String> browserTypeList = new ArrayList<String>();
        for (final String browserType : config.getBrowserTypeValues()) {
            browserTypeList.add(browserType);
        }
        defaultDataMap.put("type", browserTypeList);
        // label: labelType
        final List<String> labelTypeList = new ArrayList<String>();
        for (final String labelType : config.getLabelTypeValues()) {
            labelTypeList.add(labelType);
        }
        defaultDataMap.put("label", labelTypeList);
        // role: roleType
        final List<String> roleTypeList = new ArrayList<String>();
        for (final String roleType : config.getRoleTypeValues()) {
            roleTypeList.add(roleType);
        }
        defaultDataMap.put("role", roleTypeList);
        // mimetype
        defaultDataMap.put("mimetype", mimeType);
        // title
        // content
        // cache
        // digest
        // host
        // site
        // url
        // anchor
        // contentLength
        // lastModified
        // id

        storeData(callback, paramMap, scriptMap, defaultDataMap);

    }

    protected String convertValue(final String template,
            final Map<String, String> paramMap) {
        if (StringUtil.isEmpty(template)) {
            return Constants.EMPTY_STRING;
        }

        try {
            final Object exp = OgnlUtil.parseExpression(template);
            final Object value = OgnlUtil.getValue(exp, paramMap);
            if (value == null) {
                return Constants.EMPTY_STRING;
            }
            return value.toString();
        } catch (final Exception e) {
            logger.warn("Invalid value format: " + template, e);
            return template;
        }
    }

    protected abstract void storeData(IndexUpdateCallback callback,
            Map<String, String> paramMap, Map<String, String> scriptMap,
            Map<String, Object> defaultDataMap);
}

==> fess-fess_tags_fess-7.0.1-r1373.tar.gz: fess-fess_tags_fess-7.0.1-r1373/fess-7.0.1/src/main/java/jp/sf/fess/ds/impl/AbstractDataStoreImpl.java <==
/*
 * Copyright 2009-2012 the Fess Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package jp.sf.fess.ds.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import jp.sf.fess.Constants;
import jp.sf.fess.db.exentity.DataCrawlingConfig;
import jp.sf.fess.ds.DataStore;
import jp.sf.fess.ds.IndexUpdateCallback;
import jp.sf.fess.util.ParameterUtil;

import org.seasar.framework.util.OgnlUtil;
import org.seasar.framework.util.StringUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public abstract class AbstractDataStoreImpl implements DataStore {

    private static final Logger logger = LoggerFactory
            .getLogger(AbstractDataStoreImpl.class);

    public String mimeType = "application/datastore";

    protected boolean alive = true;

    @Override
    public void stop() {
        alive = false;
    }

    @Override
    public void store(final DataCrawlingConfig config,
            final IndexUpdateCallback callback,
            final Map<String, String> initParamMap) {
        Map<String, String> paramMap = ParameterUtil.parse(config
                .getHandlerParameter());
        final Map<String, String> scriptMap = ParameterUtil
                .parse(config.getHandlerScript());

        initParamMap.putAll(paramMap);
        paramMap = initParamMap;

        // default values
        final Map<String, Object> defaultDataMap = new HashMap<String, Object>();
        // segment
        defaultDataMap.put("segment", initParamMap.get("sessionId"));
        // tstamp
        defaultDataMap.put("tstamp", Long.toString(System.currentTimeMillis()));
        // boost
        defaultDataMap.put("boost", config.getBoost().toString());
        // type: browserType
        final List<String> browserTypeList = new ArrayList<String>();
        for (final String browserType : config.getBrowserTypeValues()) {
            browserTypeList.add(browserType);
        }
        defaultDataMap.put("type", browserTypeList);
        // label: labelType
        final List<String> labelTypeList = new ArrayList<String>();
        for (final String labelType : config.getLabelTypeValues()) {
            labelTypeList.add(labelType);
        }
        defaultDataMap.put("label", labelTypeList);
        // role: roleType
        final List<String> roleTypeList = new ArrayList<String>();
        for (final String roleType : config.getRoleTypeValues()) {
            roleTypeList.add(roleType);
        }
        defaultDataMap.put("role", roleTypeList);
        // mimetype
        defaultDataMap.put("mimetype", mimeType);
        // title
        // content
        // cache
        // digest
        // host
        // site
        // url
        // anchor
        // contentLength
        // lastModified
        // id

        storeData(callback, paramMap, scriptMap, defaultDataMap);

    }

    protected String convertValue(final String template,
            final Map<String, String> paramMap) {
        if (StringUtil.isEmpty(template)) {
            return Constants.EMPTY_STRING;
        }

        try {
            final Object exp = OgnlUtil.parseExpression(template);
            final Object value = OgnlUtil.getValue(exp, paramMap);
            if (value == null) {
                return Constants.EMPTY_STRING;
            }
            return value.toString();
        } catch (final Exception e) {
            logger.warn("Invalid value format: " + template, e);
            return Constants.EMPTY_STRING;
        }
    }

    protected long getReadInterval(final Map<String, String> paramMap) {
        long readInterval = 0;
        final String value = paramMap.get("readInterval");
        if (StringUtil.isNotBlank(value)) {
            try {
                readInterval = Long.parseLong(value);
            } catch (final NumberFormatException e) {
                logger.warn("Invalid read interval: " + value);
            }
        }
        return readInterval;
    }

    protected void sleep(final long interval) {
        try {
            Thread.sleep(interval);
        } catch (final Exception e) {
        }
    }

    protected abstract void storeData(IndexUpdateCallback callback,
            Map<String, String> paramMap, Map<String, String> scriptMap,
            Map<String, Object> defaultDataMap);
}
